<?php

namespace App\Enums;

/**
 * 优惠券使用范围枚举类
 */
enum CouponScope: int
{
    /**
     * 使用范围：全部商品
     */
    case ALL = 1;

    /**
     * 使用范围：分类商品
     */
    case CATEGORY = 2;

    /**
     * 使用范围：指定商品
     */
    case SPECIFIC = 3;

    /**
     * 获取范围的显示文本
     *
     * @return string 范围的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::ALL => '全部商品',
            self::CATEGORY => '分类商品',
            self::SPECIFIC => '指定商品',
        };
    }

    /**
     * 获取范围的整数值
     *
     * @return int 范围值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前范围是否与指定范围相同
     *
     * @param self $scope 要比较的范围
     * @return bool 如果范围相同返回 true，否则返回 false
     */
    public function is(self $scope): bool
    {
        return $this === $scope;
    }

    /**
     * 根据整数值创建对应的范围枚举实例
     *
     * @param int $value 范围值
     * @return self|null 返回对应的范围枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::ALL->value => self::ALL,
            self::CATEGORY->value => self::CATEGORY,
            self::SPECIFIC->value => self::SPECIFIC,
            default => null
        };
    }

    /**
     * 获取所有范围的值数组
     *
     * @return array 包含所有范围值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有范围的键值对数组
     *
     * @return array 范围值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::ALL->value => self::ALL->label(),
            self::CATEGORY->value => self::CATEGORY->label(),
            self::SPECIFIC->value => self::SPECIFIC->label(),
        ];
    }
}
