<?php

namespace App\Enums;

/**
 * 反馈类型枚举类
 */
enum FeedbackType: int
{
    /**
     * 反馈类型：建议反馈
     */
    case SUGGESTION = 1;

    /**
     * 反馈类型：投诉反馈
     */
    case COMPLAINT = 2;

    /**
     * 反馈类型：咨询反馈
     */
    case CONSULTATION = 3;

    /**
     * 反馈类型：故障反馈
     */
    case MALFUNCTION = 4;

    /**
     * 反馈类型：其他反馈
     */
    case OTHER = 5;

    /**
     * 获取类型的显示文本
     *
     * @return string 类型的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::SUGGESTION => '建议反馈',
            self::COMPLAINT => '投诉反馈',
            self::CONSULTATION => '咨询反馈',
            self::MALFUNCTION => '故障反馈',
            self::OTHER => '其他反馈',
        };
    }

    /**
     * 获取类型的整数值
     *
     * @return int 类型值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前类型是否与指定类型相同
     *
     * @param self $type 要比较的类型
     * @return bool 如果类型相同返回 true，否则返回 false
     */
    public function is(self $type): bool
    {
        return $this === $type;
    }

    /**
     * 根据整数值创建对应的类型枚举实例
     *
     * @param int $value 类型值
     * @return self|null 返回对应的类型枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::SUGGESTION->value => self::SUGGESTION,
            self::COMPLAINT->value => self::COMPLAINT,
            self::CONSULTATION->value => self::CONSULTATION,
            self::MALFUNCTION->value => self::MALFUNCTION,
            self::OTHER->value => self::OTHER,
            default => null
        };
    }

    /**
     * 获取所有类型的值数组
     *
     * @return array 包含所有类型值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有类型的键值对数组
     *
     * @return array 类型值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::SUGGESTION->value => self::SUGGESTION->label(),
            self::COMPLAINT->value => self::COMPLAINT->label(),
            self::CONSULTATION->value => self::CONSULTATION->label(),
            self::MALFUNCTION->value => self::MALFUNCTION->label(),
            self::OTHER->value => self::OTHER->label(),
        ];
    }
}
