<?php

namespace App\Enums;

/**
 * 营销记录状态枚举类
 */
enum MarketingRecordStatus: int
{
    /**
     * 记录状态：待使用
     */
    case PENDING = 1;

    /**
     * 记录状态：已使用
     */
    case USED = 2;

    /**
     * 记录状态：已过期
     */
    case EXPIRED = 3;

    /**
     * 记录状态：已取消
     */
    case CANCELLED = 4;

    /**
     * 获取状态的显示文本
     *
     * @return string 状态的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::PENDING => '待使用',
            self::USED => '已使用',
            self::EXPIRED => '已过期',
            self::CANCELLED => '已取消',
        };
    }

    /**
     * 获取状态的整数值
     *
     * @return int 状态值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前状态是否与指定状态相同
     *
     * @param self $status 要比较的状态
     * @return bool 如果状态相同返回 true，否则返回 false
     */
    public function is(self $status): bool
    {
        return $this === $status;
    }

    /**
     * 根据整数值创建对应的状态枚举实例
     *
     * @param int $value 状态值
     * @return self|null 返回对应的状态枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::PENDING->value => self::PENDING,
            self::USED->value => self::USED,
            self::EXPIRED->value => self::EXPIRED,
            self::CANCELLED->value => self::CANCELLED,
            default => null
        };
    }

    /**
     * 获取所有状态的值数组
     *
     * @return array 包含所有状态值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有状态的键值对数组
     *
     * @return array 状态值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::PENDING->value => self::PENDING->label(),
            self::USED->value => self::USED->label(),
            self::EXPIRED->value => self::EXPIRED->label(),
            self::CANCELLED->value => self::CANCELLED->label(),
        ];
    }
}
