<?php

namespace App\Enums;

/**
 * 营销状态枚举类
 */
enum MarketingStatus: int
{
    /**
     * 营销状态：未开始
     */
    case PENDING = 1;

    /**
     * 营销状态：进行中
     */
    case PROCESSING = 2;

    /**
     * 营销状态：已结束
     */
    case ENDED = 3;

    /**
     * 获取状态的显示文本
     *
     * @return string 状态的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::PENDING => '未开始',
            self::PROCESSING => '进行中',
            self::ENDED => '已结束',
        };
    }

    /**
     * 获取状态的整数值
     *
     * @return int 状态值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前状态是否与指定状态相同
     *
     * @param self $status 要比较的状态
     * @return bool 如果状态相同返回 true，否则返回 false
     */
    public function is(self $status): bool
    {
        return $this === $status;
    }

    /**
     * 根据整数值创建对应的状态枚举实例
     *
     * @param int $value 状态值
     * @return self|null 返回对应的状态枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::PENDING->value => self::PENDING,
            self::PROCESSING->value => self::PROCESSING,
            self::ENDED->value => self::ENDED,
            default => null
        };
    }

    /**
     * 获取所有状态的值数组
     *
     * @return array 包含所有状态值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有状态的键值对数组
     *
     * @return array 状态值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::PENDING->value => self::PENDING->label(),
            self::PROCESSING->value => self::PROCESSING->label(),
            self::ENDED->value => self::ENDED->label(),
        ];
    }
}
