<?php

namespace App\Enums;

/**
 * 订单分销类型枚举类
 */
enum OrderDistributionType: int
{
    /**
     * 分销类型：平台分销
     */
    case PLATFORM = 1;

    /**
     * 分销类型：店铺分销
     */
    case SHOP = 2;

    /**
     * 分销类型：个人分销
     */
    case PERSONAL = 3;

    /**
     * 分销类型：团队分销
     */
    case TEAM = 4;

    /**
     * 获取类型的显示文本
     *
     * @return string 类型的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::PLATFORM => '平台分销',
            self::SHOP => '店铺分销',
            self::PERSONAL => '个人分销',
            self::TEAM => '团队分销',
        };
    }

    /**
     * 获取类型的整数值
     *
     * @return int 类型值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前类型是否与指定类型相同
     *
     * @param self $type 要比较的类型
     * @return bool 如果类型相同返回 true，否则返回 false
     */
    public function is(self $type): bool
    {
        return $this === $type;
    }

    /**
     * 根据整数值创建对应的类型枚举实例
     *
     * @param int $value 类型值
     * @return self|null 返回对应的类型枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::PLATFORM->value => self::PLATFORM,
            self::SHOP->value => self::SHOP,
            self::PERSONAL->value => self::PERSONAL,
            self::TEAM->value => self::TEAM,
            default => null
        };
    }

    /**
     * 获取所有类型的值数组
     *
     * @return array 包含所有类型值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有类型的键值对数组
     *
     * @return array 类型值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::PLATFORM->value => self::PLATFORM->label(),
            self::SHOP->value => self::SHOP->label(),
            self::PERSONAL->value => self::PERSONAL->label(),
            self::TEAM->value => self::TEAM->label(),
        ];
    }
}
