<?php

namespace App\Enums;

/**
 * 订单记录状态枚举类
 */
enum OrderRecordStatus: int
{
    /**
     * 记录状态：创建订单
     */
    case CREATED = 1;

    /**
     * 记录状态：支付完成
     */
    case PAID = 2;

    /**
     * 记录状态：已分配技师
     */
    case ASSIGNED = 3;

    /**
     * 记录状态：技师到达
     */
    case ARRIVED = 4;

    /**
     * 记录状态：开始服务
     */
    case STARTED = 5;

    /**
     * 记录状态：服务完成
     */
    case COMPLETED = 6;

    /**
     * 记录状态：已评价
     */
    case EVALUATED = 7;

    /**
     * 记录状态：已取消
     */
    case CANCELLED = 8;

    /**
     * 获取状态的显示文本
     *
     * @return string 状态的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::CREATED => '创建订单',
            self::PAID => '支付完成',
            self::ASSIGNED => '已分配技师',
            self::ARRIVED => '技师到达',
            self::STARTED => '开始服务',
            self::COMPLETED => '服务完成',
            self::EVALUATED => '已评价',
            self::CANCELLED => '已取消',
        };
    }

    /**
     * 获取状态的整数值
     *
     * @return int 状态值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前状态是否与指定状态相同
     *
     * @param self $status 要比较的状态
     * @return bool 如果状态相同返回 true，否则返回 false
     */
    public function is(self $status): bool
    {
        return $this === $status;
    }

    /**
     * 根据整数值创建对应的状态枚举实例
     *
     * @param int $value 状态值
     * @return self|null 返回对应的状态枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::CREATED->value => self::CREATED,
            self::PAID->value => self::PAID,
            self::ASSIGNED->value => self::ASSIGNED,
            self::ARRIVED->value => self::ARRIVED,
            self::STARTED->value => self::STARTED,
            self::COMPLETED->value => self::COMPLETED,
            self::EVALUATED->value => self::EVALUATED,
            self::CANCELLED->value => self::CANCELLED,
            default => null
        };
    }

    /**
     * 获取所有状态的值数组
     *
     * @return array 包含所有状态值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有状态的键值对数组
     *
     * @return array 状态值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::CREATED->value => self::CREATED->label(),
            self::PAID->value => self::PAID->label(),
            self::ASSIGNED->value => self::ASSIGNED->label(),
            self::ARRIVED->value => self::ARRIVED->label(),
            self::STARTED->value => self::STARTED->label(),
            self::COMPLETED->value => self::COMPLETED->label(),
            self::EVALUATED->value => self::EVALUATED->label(),
            self::CANCELLED->value => self::CANCELLED->label(),
        ];
    }
}
