<?php

namespace App\Enums;

/**
 * 订单来源枚举类
 */
enum OrderSource: int
{
    /**
     * 订单来源：平台
     */
    case PLATFORM = 1;

    /**
     * 订单来源：店铺
     */
    case SHOP = 2;

    /**
     * 获取来源的显示文本
     *
     * @return string 来源的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::PLATFORM => '平台',
            self::SHOP => '店铺',
        };
    }

    /**
     * 获取来源的整数值
     *
     * @return int 来源值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前来源是否与指定来源相同
     *
     * @param self $source 要比较的来源
     * @return bool 如果来源相同返回 true，否则返回 false
     */
    public function is(self $source): bool
    {
        return $this === $source;
    }

    /**
     * 根据整数值创建对应的来源枚举实例
     *
     * @param int $value 来源值
     * @return self|null 返回对应的来源枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::PLATFORM->value => self::PLATFORM,
            self::SHOP->value => self::SHOP,
            default => null
        };
    }

    /**
     * 获取所有来源的值数组
     *
     * @return array 包含所有来源值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有来源的键值对数组
     *
     * @return array 来源值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::PLATFORM->value => self::PLATFORM->label(),
            self::SHOP->value => self::SHOP->label(),
        ];
    }
}
