<?php

namespace App\Enums;

/**
 * 订单类型枚举类
 */
enum OrderType: int
{
    /**
     * 订单类型：上门
     */
    case VISIT = 1;

    /**
     * 订单类型：抢单
     */
    case GRAB = 2;

    /**
     * 订单类型：加钟
     */
    case OVERTIME = 3;

    /**
     * 订单类型：到店
     */
    case SHOP = 4;

    /**
     * 订单类型：应急
     */
    case EMERGENCY = 5;

    /**
     * 获取类型的显示文本
     *
     * @return string 类型的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::VISIT => '上门',
            self::GRAB => '抢单',
            self::OVERTIME => '加钟',
            self::SHOP => '到店',
            self::EMERGENCY => '应急',
        };
    }

    /**
     * 获取类型的整数值
     *
     * @return int 类型值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前类型是否与指定类型相同
     *
     * @param self $type 要比较的类型
     * @return bool 如果类型相同返回 true，否则返回 false
     */
    public function is(self $type): bool
    {
        return $this === $type;
    }

    /**
     * 根据整数值创建对应的类型枚举实例
     *
     * @param int $value 类型值
     * @return self|null 返回对应的类型枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::VISIT->value => self::VISIT,
            self::GRAB->value => self::GRAB,
            self::OVERTIME->value => self::OVERTIME,
            self::SHOP->value => self::SHOP,
            self::EMERGENCY->value => self::EMERGENCY,
            default => null
        };
    }

    /**
     * 获取所有类型的值数组
     *
     * @return array 包含所有类型值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有类型的键值对数组
     *
     * @return array 类型值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::VISIT->value => self::VISIT->label(),
            self::GRAB->value => self::GRAB->label(),
            self::OVERTIME->value => self::OVERTIME->label(),
            self::SHOP->value => self::SHOP->label(),
            self::EMERGENCY->value => self::EMERGENCY->label(),
        ];
    }
}
