<?php

namespace App\Enums;

/**
 * 支付方式枚举类
 */
enum PaymentMethod: int
{
    /**
     * 支付方式：微信支付
     */
    case WECHAT = 1;

    /**
     * 支付方式：支付宝
     */
    case ALIPAY = 2;

    /**
     * 支付方式：余额支付
     */
    case BALANCE = 3;

    /**
     * 支付方式：混合支付
     */
    case MIXED = 4;

    /**
     * 获取方式的显示文本
     *
     * @return string 方式的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::WECHAT => '微信支付',
            self::ALIPAY => '支付宝',
            self::BALANCE => '余额支付',
            self::MIXED => '混合支付',
        };
    }

    /**
     * 获取方式的整数值
     *
     * @return int 方式值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前方式是否与指定方式相同
     *
     * @param self $method 要比较的方式
     * @return bool 如果方式相同返回 true，否则返回 false
     */
    public function is(self $method): bool
    {
        return $this === $method;
    }

    /**
     * 根据整数值创建对应的方式枚举实例
     *
     * @param int $value 方式值
     * @return self|null 返回对应的方式枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::WECHAT->value => self::WECHAT,
            self::ALIPAY->value => self::ALIPAY,
            self::BALANCE->value => self::BALANCE,
            self::MIXED->value => self::MIXED,
            default => null
        };
    }

    /**
     * 获取所有方式的值数组
     *
     * @return array 包含所有方式值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有方式的键值对数组
     *
     * @return array 方式值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::WECHAT->value => self::WECHAT->label(),
            self::ALIPAY->value => self::ALIPAY->label(),
            self::BALANCE->value => self::BALANCE->label(),
            self::MIXED->value => self::MIXED->label(),
        ];
    }
}
