<?php

namespace App\Enums;

/**
 * 分账类型枚举类
 */
enum ProfitType: int
{
    /**
     * 分账类型：平台分账
     */
    case PLATFORM = 1;

    /**
     * 分账类型：店铺分账
     */
    case SHOP = 2;

    /**
     * 分账类型：技师分账
     */
    case TECHNICIAN = 3;

    /**
     * 分账类型：代理商分账
     */
    case AGENT = 4;

    /**
     * 分账类型：推广员分账
     */
    case PROMOTER = 5;

    /**
     * 获取类型的显示文本
     *
     * @return string 类型的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::PLATFORM => '平台分账',
            self::SHOP => '店铺分账',
            self::TECHNICIAN => '技师分账',
            self::AGENT => '代理商分账',
            self::PROMOTER => '推广员分账',
        };
    }

    /**
     * 获取类型的整数值
     *
     * @return int 类型值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前类型是否与指定类型相同
     *
     * @param self $type 要比较的类型
     * @return bool 如果类型相同返回 true，否则返回 false
     */
    public function is(self $type): bool
    {
        return $this === $type;
    }

    /**
     * 根据整数值创建对应的类型枚举实例
     *
     * @param int $value 类型值
     * @return self|null 返回对应的类型枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::PLATFORM->value => self::PLATFORM,
            self::SHOP->value => self::SHOP,
            self::TECHNICIAN->value => self::TECHNICIAN,
            self::AGENT->value => self::AGENT,
            self::PROMOTER->value => self::PROMOTER,
            default => null
        };
    }

    /**
     * 获取所有类型的值数组
     *
     * @return array 包含所有类型值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有类型的键值对数组
     *
     * @return array 类型值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::PLATFORM->value => self::PLATFORM->label(),
            self::SHOP->value => self::SHOP->label(),
            self::TECHNICIAN->value => self::TECHNICIAN->label(),
            self::AGENT->value => self::AGENT->label(),
            self::PROMOTER->value => self::PROMOTER->label(),
        ];
    }
}
