<?php

namespace App\Enums;

/**
 * 充值来源枚举类
 */
enum RechargeSource: int
{
    /**
     * 充值来源：微信
     */
    case WECHAT = 1;

    /**
     * 充值来源：支付宝
     */
    case ALIPAY = 2;

    /**
     * 充值来源：银行卡
     */
    case BANK = 3;

    /**
     * 充值来源：其他
     */
    case OTHER = 4;

    /**
     * 获取来源的显示文本
     *
     * @return string 来源的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::WECHAT => '微信',
            self::ALIPAY => '支付宝',
            self::BANK => '银行卡',
            self::OTHER => '其他',
        };
    }

    /**
     * 获取来源的整数值
     *
     * @return int 来源值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前来源是否与指定来源相同
     *
     * @param self $source 要比较的来源
     * @return bool 如果来源相同返回 true，否则返回 false
     */
    public function is(self $source): bool
    {
        return $this === $source;
    }

    /**
     * 根据整数值创建对应的来源枚举实例
     *
     * @param int $value 来源值
     * @return self|null 返回对应的来源枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::WECHAT->value => self::WECHAT,
            self::ALIPAY->value => self::ALIPAY,
            self::BANK->value => self::BANK,
            self::OTHER->value => self::OTHER,
            default => null
        };
    }

    /**
     * 获取所有来源的值数组
     *
     * @return array 包含所有来源值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有来源的键值对数组
     *
     * @return array 来源值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::WECHAT->value => self::WECHAT->label(),
            self::ALIPAY->value => self::ALIPAY->label(),
            self::BANK->value => self::BANK->label(),
            self::OTHER->value => self::OTHER->label(),
        ];
    }
}
