<?php

namespace App\Enums;

/**
 * 退款方式枚举类
 */
enum RefundMethod: int
{
    /**
     * 退款方式：原路退回
     */
    case ORIGINAL = 1;

    /**
     * 退款方式：退回余额
     */
    case BALANCE = 2;

    /**
     * 退款方式：人工处理
     */
    case MANUAL = 3;

    /**
     * 获取方式的显示文本
     *
     * @return string 方式的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::ORIGINAL => '原路退回',
            self::BALANCE => '退回余额',
            self::MANUAL => '人工处理',
        };
    }

    /**
     * 获取方式的整数值
     *
     * @return int 方式值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前方式是否与指定方式相同
     *
     * @param self $method 要比较的方式
     * @return bool 如果方式相同返回 true，否则返回 false
     */
    public function is(self $method): bool
    {
        return $this === $method;
    }

    /**
     * 根据整数值创建对应的方式枚举实例
     *
     * @param int $value 方式值
     * @return self|null 返回对应的方式枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::ORIGINAL->value => self::ORIGINAL,
            self::BALANCE->value => self::BALANCE,
            self::MANUAL->value => self::MANUAL,
            default => null
        };
    }

    /**
     * 获取所有方式的值数组
     *
     * @return array 包含所有方式值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有方式的键值对数组
     *
     * @return array 方式值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::ORIGINAL->value => self::ORIGINAL->label(),
            self::BALANCE->value => self::BALANCE->label(),
            self::MANUAL->value => self::MANUAL->label(),
        ];
    }
}
