<?php

namespace App\Enums;

/**
 * 店铺类型枚举类
 */
enum ShopType: int
{
    /**
     * 店铺类型：直营店
     */
    case DIRECT = 1;

    /**
     * 店铺类型：加盟店
     */
    case FRANCHISE = 2;

    /**
     * 店铺类型：合作店
     */
    case COOPERATION = 3;

    /**
     * 店铺类型：联盟店
     */
    case ALLIANCE = 4;

    /**
     * 获取类型的显示文本
     *
     * @return string 类型的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::DIRECT => '直营店',
            self::FRANCHISE => '加盟店',
            self::COOPERATION => '合作店',
            self::ALLIANCE => '联盟店',
        };
    }

    /**
     * 获取类型的整数值
     *
     * @return int 类型值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前类型是否与指定类型相同
     *
     * @param self $type 要比较的类型
     * @return bool 如果类型相同返回 true，否则返回 false
     */
    public function is(self $type): bool
    {
        return $this === $type;
    }

    /**
     * 根据整数值创建对应的类型枚举实例
     *
     * @param int $value 类型值
     * @return self|null 返回对应的类型枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::DIRECT->value => self::DIRECT,
            self::FRANCHISE->value => self::FRANCHISE,
            self::COOPERATION->value => self::COOPERATION,
            self::ALLIANCE->value => self::ALLIANCE,
            default => null
        };
    }

    /**
     * 获取所有类型的值数组
     *
     * @return array 包含所有类型值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有类型的键值对数组
     *
     * @return array 类型值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::DIRECT->value => self::DIRECT->label(),
            self::FRANCHISE->value => self::FRANCHISE->label(),
            self::COOPERATION->value => self::COOPERATION->label(),
            self::ALLIANCE->value => self::ALLIANCE->label(),
        ];
    }
}
