<?php

namespace App\Enums;

/**
 * 通用审核状态枚举类
 */
enum SysAuditStatus: int
{
    /**
     * 审核状态：待审核
     */
    case PENDING = 1;

    /**
     * 审核状态：通过
     */
    case PASSED = 2;

    /**
     * 审核状态：拒绝
     */
    case REJECTED = 3;

    /**
     * 获取状态的显示文本
     *
     * @return string 状态的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::PENDING => '待审核',
            self::PASSED => '通过',
            self::REJECTED => '拒绝',
        };
    }

    /**
     * 获取状态的整数值
     *
     * @return int 状态值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前状态是否与指定状态相同
     *
     * @param self $status 要比较的状态
     * @return bool 如果状态相同返回 true，否则返回 false
     */
    public function is(self $status): bool
    {
        return $this === $status;
    }

    /**
     * 根据整数值创建对应的状态枚举实例
     *
     * @param int $value 状态值
     * @return self|null 返回对应的状态枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::PENDING->value => self::PENDING,
            self::PASSED->value => self::PASSED,
            self::REJECTED->value => self::REJECTED,
            default => null
        };
    }

    /**
     * 获取所有状态的值数组
     *
     * @return array 包含所有状态值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有状态的键值对数组
     *
     * @return array 状态值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::PENDING->value => self::PENDING->label(),
            self::PASSED->value => self::PASSED->label(),
            self::REJECTED->value => self::REJECTED->label(),
        ];
    }
}
