<?php

namespace App\Enums;

/**
 * 缓存类型枚举类
 */
enum SysCacheType: int
{
    /**
     * 缓存类型：内存缓存
     */
    case MEMORY = 1;

    /**
     * 缓存类型：Redis缓存
     */
    case REDIS = 2;

    /**
     * 缓存类型：本地缓存
     */
    case LOCAL = 3;

    /**
     * 缓存类型：混合缓存
     */
    case HYBRID = 4;

    /**
     * 获取类型的显示文本
     *
     * @return string 类型的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::MEMORY => '内存缓存',
            self::REDIS => 'Redis缓存',
            self::LOCAL => '本地缓存',
            self::HYBRID => '混合缓存',
        };
    }

    /**
     * 获取类型的整数值
     *
     * @return int 类型值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前类型是否与指定类型相同
     *
     * @param self $type 要比较的类型
     * @return bool 如果类型相同返回 true，否则返回 false
     */
    public function is(self $type): bool
    {
        return $this === $type;
    }

    /**
     * 根据整数值创建对应的类型枚举实例
     *
     * @param int $value 类型值
     * @return self|null 返回对应的类型枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::MEMORY->value => self::MEMORY,
            self::REDIS->value => self::REDIS,
            self::LOCAL->value => self::LOCAL,
            self::HYBRID->value => self::HYBRID,
            default => null
        };
    }

    /**
     * 获取所有类型的值数组
     *
     * @return array 包含所有类型值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有类型的键值对数组
     *
     * @return array 类型值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::MEMORY->value => self::MEMORY->label(),
            self::REDIS->value => self::REDIS->label(),
            self::LOCAL->value => self::LOCAL->label(),
            self::HYBRID->value => self::HYBRID->label(),
        ];
    }
}
