<?php

namespace App\Enums;

/**
 * 系统参数类型枚举类
 */
enum SysParameterType: int
{
    /**
     * 参数类型：系统参数
     */
    case SYSTEM = 1;

    /**
     * 参数类型：业务参数
     */
    case BUSINESS = 2;

    /**
     * 参数类型：配置参数
     */
    case CONFIG = 3;

    /**
     * 参数类型：其他参数
     */
    case OTHER = 4;

    /**
     * 获取类型的显示文本
     *
     * @return string 类型的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::SYSTEM => '系统参数',
            self::BUSINESS => '业务参数',
            self::CONFIG => '配置参数',
            self::OTHER => '其他参数',
        };
    }

    /**
     * 获取类型的整数值
     *
     * @return int 类型值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前类型是否与指定类型相同
     *
     * @param self $type 要比较的类型
     * @return bool 如果类型相同返回 true，否则返回 false
     */
    public function is(self $type): bool
    {
        return $this === $type;
    }

    /**
     * 根据整数值创建对应的类型枚举实例
     *
     * @param int $value 类型值
     * @return self|null 返回对应的类型枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::SYSTEM->value => self::SYSTEM,
            self::BUSINESS->value => self::BUSINESS,
            self::CONFIG->value => self::CONFIG,
            self::OTHER->value => self::OTHER,
            default => null
        };
    }

    /**
     * 获取所有类型的值数组
     *
     * @return array 包含所有类型值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有类型的键值对数组
     *
     * @return array 类型值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::SYSTEM->value => self::SYSTEM->label(),
            self::BUSINESS->value => self::BUSINESS->label(),
            self::CONFIG->value => self::CONFIG->label(),
            self::OTHER->value => self::OTHER->label(),
        ];
    }
}
