<?php

namespace App\Enums;

/**
 * 通用状态枚举类
 */
enum SysStatus: int
{
    /**
     * 状态：启用
     */
    case ENABLE = 1;

    /**
     * 状态：禁用
     */
    case DISABLE = 2;

    /**
     * 获取状态的显示文本
     *
     * @return string 状态的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::ENABLE => '启用',
            self::DISABLE => '禁用',
        };
    }

    /**
     * 获取状态的整数值
     *
     * @return int 状态值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前状态是否与指定状态相同
     *
     * @param self $status 要比较的状态
     * @return bool 如果状态相同返回 true，否则返回 false
     */
    public function is(self $status): bool
    {
        return $this === $status;
    }

    /**
     * 根据整数值创建对应的状态枚举实例
     *
     * @param int $value 状态值
     * @return self|null 返回对应的状态枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::ENABLE->value => self::ENABLE,
            self::DISABLE->value => self::DISABLE,
            default => null
        };
    }

    /**
     * 获取所有状态的值数组
     *
     * @return array 包含所有状态值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有状态的键值对数组
     *
     * @return array 状态值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::ENABLE->value => self::ENABLE->label(),
            self::DISABLE->value => self::DISABLE->label(),
        ];
    }
}
