<?php

namespace App\Enums;

/**
 * 技师报警类型枚举类
 */
enum TechnicianAlarmType: int
{
    /**
     * 报警类型：紧急求助
     */
    case EMERGENCY = 1;

    /**
     * 报警类型：骚扰投诉
     */
    case HARASSMENT = 2;

    /**
     * 报警类型：纠纷
     */
    case DISPUTE = 3;

    /**
     * 报警类型：其他
     */
    case OTHER = 4;

    /**
     * 获取类型的显示文本
     *
     * @return string 类型的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::EMERGENCY => '紧急求助',
            self::HARASSMENT => '骚扰投诉',
            self::DISPUTE => '纠纷',
            self::OTHER => '其他',
        };
    }

    /**
     * 获取类型的整数值
     *
     * @return int 类型值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前类型是否与指定类型相同
     *
     * @param self $type 要比较的类型
     * @return bool 如果类型相同返回 true，否则返回 false
     */
    public function is(self $type): bool
    {
        return $this === $type;
    }

    /**
     * 根据整数值创建对应的类型枚举实例
     *
     * @param int $value 类型值
     * @return self|null 返回对应的类型枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::EMERGENCY->value => self::EMERGENCY,
            self::HARASSMENT->value => self::HARASSMENT,
            self::DISPUTE->value => self::DISPUTE,
            self::OTHER->value => self::OTHER,
            default => null
        };
    }

    /**
     * 获取所有类型的值数组
     *
     * @return array 包含所有类型值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有类型的键值对数组
     *
     * @return array 类型值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::EMERGENCY->value => self::EMERGENCY->label(),
            self::HARASSMENT->value => self::HARASSMENT->label(),
            self::DISPUTE->value => self::DISPUTE->label(),
            self::OTHER->value => self::OTHER->label(),
        ];
    }
}
