<?php

namespace App\Enums;

/**
 * 技师经验来源枚举类
 */
enum TechnicianExpSource: int
{
    /**
     * 经验来源：订单
     */
    case ORDER = 1;

    /**
     * 经验来源：加钟
     */
    case OVERTIME = 2;

    /**
     * 经验来源：评价
     */
    case COMMENT = 3;

    /**
     * 经验来源：推广
     */
    case PROMOTION = 4;

    /**
     * 获取来源的显示文本
     *
     * @return string 来源的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::ORDER => '订单',
            self::OVERTIME => '加钟',
            self::COMMENT => '评价',
            self::PROMOTION => '推广',
        };
    }

    /**
     * 获取来源的整数值
     *
     * @return int 来源值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前来源是否与指定来源相同
     *
     * @param self $source 要比较的来源
     * @return bool 如果来源相同返回 true，否则返回 false
     */
    public function is(self $source): bool
    {
        return $this === $source;
    }

    /**
     * 根据整数值创建对应的来源枚举实例
     *
     * @param int $value 来源值
     * @return self|null 返回对应的来源枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::ORDER->value => self::ORDER,
            self::OVERTIME->value => self::OVERTIME,
            self::COMMENT->value => self::COMMENT,
            self::PROMOTION->value => self::PROMOTION,
            default => null
        };
    }

    /**
     * 获取所有来源的值数组
     *
     * @return array 包含所有来源值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有来源的键值对数组
     *
     * @return array 来源值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::ORDER->value => self::ORDER->label(),
            self::OVERTIME->value => self::OVERTIME->label(),
            self::COMMENT->value => self::COMMENT->label(),
            self::PROMOTION->value => self::PROMOTION->label(),
        ];
    }
}
