<?php

namespace App\Enums;

/**
 * 技师状态枚举类
 */
enum TechnicianStatus: int
{
    /**
     * 技师状态：待认证
     */
    case PENDING = 1;

    /**
     * 技师状态：正常服务
     */
    case ACTIVE = 2;

    /**
     * 技师状态：暂停服务
     */
    case SUSPENDED = 3;

    /**
     * 技师状态：黑名单
     */
    case BLACKLIST = 4;

    /**
     * 技师状态：已终止
     */
    case TERMINATED = 5;

    /**
     * 获取状态的显示文本
     *
     * @return string 状态的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::PENDING => '待认证',
            self::ACTIVE => '正常服务',
            self::SUSPENDED => '暂停服务',
            self::BLACKLIST => '黑名单',
            self::TERMINATED => '已终止',
        };
    }

    /**
     * 获取状态的整数值
     *
     * @return int 状态值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前状态是否与指定状态相同
     *
     * @param self $status 要比较的状态
     * @return bool 如果状态相同返回 true，否则返回 false
     */
    public function is(self $status): bool
    {
        return $this === $status;
    }

    /**
     * 根据整数值创建对应的状态枚举实例
     *
     * @param int $value 状态值
     * @return self|null 返回对应的状态枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::PENDING->value => self::PENDING,
            self::ACTIVE->value => self::ACTIVE,
            self::SUSPENDED->value => self::SUSPENDED,
            self::BLACKLIST->value => self::BLACKLIST,
            self::TERMINATED->value => self::TERMINATED,
            default => null
        };
    }

    /**
     * 获取所有状态的值数组
     *
     * @return array 包含所有状态值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有状态的键值对数组
     *
     * @return array 状态值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::PENDING->value => self::PENDING->label(),
            self::ACTIVE->value => self::ACTIVE->label(),
            self::SUSPENDED->value => self::SUSPENDED->label(),
            self::BLACKLIST->value => self::BLACKLIST->label(),
            self::TERMINATED->value => self::TERMINATED->label(),
        ];
    }
}
