<?php

namespace App\Enums;

/**
 * 交易方向枚举类
 */
enum TransactionDirection: int
{
    /**
     * 交易方向：收入
     */
    case IN = 1;

    /**
     * 交易方向：支出
     */
    case OUT = 2;

    /**
     * 获取方向的显示文本
     *
     * @return string 方向的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::IN => '收入',
            self::OUT => '支出',
        };
    }

    /**
     * 获取方向的整数值
     *
     * @return int 方向值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前方向是否与指定方向相同
     *
     * @param self $direction 要比较的方向
     * @return bool 如果方向相同返回 true，否则返回 false
     */
    public function is(self $direction): bool
    {
        return $this === $direction;
    }

    /**
     * 根据整数值创建对应的方向枚举实例
     *
     * @param int $value 方向值
     * @return self|null 返回对应的方向枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::IN->value => self::IN,
            self::OUT->value => self::OUT,
            default => null
        };
    }

    /**
     * 获取所有方向的值数组
     *
     * @return array 包含所有方向值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有方向的键值对数组
     *
     * @return array 方向值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::IN->value => self::IN->label(),
            self::OUT->value => self::OUT->label(),
        ];
    }
}
