<?php

namespace App\Enums;

/**
 * 交易类型枚举类
 */
enum TransactionType: int
{
    /**
     * 交易类型：充值
     */
    case RECHARGE = 1;

    /**
     * 交易类型：提现
     */
    case WITHDRAW = 2;

    /**
     * 交易类型：支付
     */
    case PAYMENT = 3;

    /**
     * 交易类型：退款
     */
    case REFUND = 4;

    /**
     * 交易类型：佣金
     */
    case COMMISSION = 5;

    /**
     * 交易类型：奖励
     */
    case BONUS = 6;

    /**
     * 交易类型：罚款
     */
    case PENALTY = 7;

    /**
     * 获取类型的显示文本
     *
     * @return string 类型的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::RECHARGE => '充值',
            self::WITHDRAW => '提现',
            self::PAYMENT => '支付',
            self::REFUND => '退款',
            self::COMMISSION => '佣金',
            self::BONUS => '奖励',
            self::PENALTY => '罚款',
        };
    }

    /**
     * 获取类型的整数值
     *
     * @return int 类型值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前类型是否与指定类型相同
     *
     * @param self $type 要比较的类型
     * @return bool 如果类型相同返回 true，否则返回 false
     */
    public function is(self $type): bool
    {
        return $this === $type;
    }

    /**
     * 根据整数值创建对应的类型枚举实例
     *
     * @param int $value 类型值
     * @return self|null 返回对应的类型枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::RECHARGE->value => self::RECHARGE,
            self::WITHDRAW->value => self::WITHDRAW,
            self::PAYMENT->value => self::PAYMENT,
            self::REFUND->value => self::REFUND,
            self::COMMISSION->value => self::COMMISSION,
            self::BONUS->value => self::BONUS,
            self::PENALTY->value => self::PENALTY,
            default => null
        };
    }

    /**
     * 获取所有类型的值数组
     *
     * @return array 包含所有类型值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有类型的键值对数组
     *
     * @return array 类型值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::RECHARGE->value => self::RECHARGE->label(),
            self::WITHDRAW->value => self::WITHDRAW->label(),
            self::PAYMENT->value => self::PAYMENT->label(),
            self::REFUND->value => self::REFUND->label(),
            self::COMMISSION->value => self::COMMISSION->label(),
            self::BONUS->value => self::BONUS->label(),
            self::PENALTY->value => self::PENALTY->label(),
        ];
    }
}
