<?php

namespace App\Enums;

/**
 * 用户类型枚举类
 */
enum UserType: int
{
    /**
     * 用户类型：普通用户
     */
    case NORMAL = 1;

    /**
     * 用户类型：VIP用户
     */
    case VIP = 2;

    /**
     * 用户类型：商户
     */
    case MERCHANT = 3;

    /**
     * 用户类型：运营人员
     */
    case OPERATOR = 4;

    /**
     * 用户类型：管理员
     */
    case ADMIN = 5;

    /**
     * 获取类型的显示文本
     *
     * @return string 类型的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::NORMAL => '普通用户',
            self::VIP => 'VIP用户',
            self::MERCHANT => '商户',
            self::OPERATOR => '运营人员',
            self::ADMIN => '管理员',
        };
    }

    /**
     * 获取类型的整数值
     *
     * @return int 类型值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前类型是否与指定类型相同
     *
     * @param self $type 要比较的类型
     * @return bool 如果类型相同返回 true，否则返回 false
     */
    public function is(self $type): bool
    {
        return $this === $type;
    }

    /**
     * 根据整数值创建对应的类型枚举实例
     *
     * @param int $value 类型值
     * @return self|null 返回对应的类型枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::NORMAL->value => self::NORMAL,
            self::VIP->value => self::VIP,
            self::MERCHANT->value => self::MERCHANT,
            self::OPERATOR->value => self::OPERATOR,
            self::ADMIN->value => self::ADMIN,
            default => null
        };
    }

    /**
     * 获取所有类型的值数组
     *
     * @return array 包含所有类型值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有类型的键值对数组
     *
     * @return array 类型值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::NORMAL->value => self::NORMAL->label(),
            self::VIP->value => self::VIP->label(),
            self::MERCHANT->value => self::MERCHANT->label(),
            self::OPERATOR->value => self::OPERATOR->label(),
            self::ADMIN->value => self::ADMIN->label(),
        ];
    }
}
