<?php

namespace App\Enums;

/**
 * 钱包类型枚举类
 */
enum WalletType: int
{
    /**
     * 钱包类型：平台自有资金钱包
     */
    case PLATFORM = 1;

    /**
     * 钱包类型：平台代收代付钱包
     */
    case ESCROW = 2;

    /**
     * 钱包类型：个人钱包
     */
    case PERSONAL = 3;

    /**
     * 钱包类型：商户钱包
     */
    case MERCHANT = 4;

    /**
     * 获取类型的显示文本
     *
     * @return string 类型的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::PLATFORM => '平台自有资金钱包',
            self::ESCROW => '平台代收代付钱包',
            self::PERSONAL => '个人钱包',
            self::MERCHANT => '商户钱包',
        };
    }

    /**
     * 获取类型的整数值
     *
     * @return int 类型值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前类型是否与指定类型相同
     *
     * @param self $type 要比较的类型
     * @return bool 如果类型相同返回 true，否则返回 false
     */
    public function is(self $type): bool
    {
        return $this === $type;
    }

    /**
     * 根据整数值创建对应的类型枚举实例
     *
     * @param int $value 类型值
     * @return self|null 返回对应的类型枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::PLATFORM->value => self::PLATFORM,
            self::ESCROW->value => self::ESCROW,
            self::PERSONAL->value => self::PERSONAL,
            self::MERCHANT->value => self::MERCHANT,
            default => null
        };
    }

    /**
     * 获取所有类型的值数组
     *
     * @return array 包含所有类型值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有类型的键值对数组
     *
     * @return array 类型值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::PLATFORM->value => self::PLATFORM->label(),
            self::ESCROW->value => self::ESCROW->label(),
            self::PERSONAL->value => self::PERSONAL->label(),
            self::MERCHANT->value => self::MERCHANT->label(),
        ];
    }
}
