<?php

namespace App\Enums;

/**
 * 提现方式枚举类
 */
enum WithdrawMethod: int
{
    /**
     * 提现方式：微信
     */
    case WECHAT = 1;

    /**
     * 提现方式：支付宝
     */
    case ALIPAY = 2;

    /**
     * 提现方式：银行卡
     */
    case BANK = 3;

    /**
     * 获取方式的显示文本
     *
     * @return string 方式的中文描述
     */
    public function label(): string
    {
        return match($this) {
            self::WECHAT => '微信',
            self::ALIPAY => '支付宝',
            self::BANK => '银行卡',
        };
    }

    /**
     * 获取方式的整数值
     *
     * @return int 方式值
     */
    public function value(): int
    {
        return $this->value;
    }

    /**
     * 检查当前方式是否与指定方式相同
     *
     * @param self $method 要比较的方式
     * @return bool 如果方式相同返回 true，否则返回 false
     */
    public function is(self $method): bool
    {
        return $this === $method;
    }

    /**
     * 根据整数值创建对应的方式枚举实例
     *
     * @param int $value 方式值
     * @return self|null 返回对应的方式枚举实例，如果值无效则返回 null
     */
    public static function fromValue(int $value): ?self
    {
        return match($value) {
            self::WECHAT->value => self::WECHAT,
            self::ALIPAY->value => self::ALIPAY,
            self::BANK->value => self::BANK,
            default => null
        };
    }

    /**
     * 获取所有方式的值数组
     *
     * @return array 包含所有方式值的数组
     */
    public static function values(): array
    {
        return array_column(self::cases(), 'value');
    }

    /**
     * 获取所有方式的键值对数组
     *
     * @return array 方式值作为键，显示文本作为值的关联数组
     */
    public static function all(): array
    {
        return [
            self::WECHAT->value => self::WECHAT->label(),
            self::ALIPAY->value => self::ALIPAY->label(),
            self::BANK->value => self::BANK->label(),
        ];
    }
}
